# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetLogsResult',
    'AwaitableGetLogsResult',
    'get_logs',
    'get_logs_output',
]

@pulumi.output_type
class GetLogsResult:
    """
    A collection of values returned by getLogs.
    """
    def __init__(__self__, details=None, discard_headers=None, follow=None, id=None, logs_list_string_enabled=None, logs_list_strings=None, name=None, show_stderr=None, show_stdout=None, since=None, tail=None, timestamps=None, until=None):
        if details and not isinstance(details, bool):
            raise TypeError("Expected argument 'details' to be a bool")
        pulumi.set(__self__, "details", details)
        if discard_headers and not isinstance(discard_headers, bool):
            raise TypeError("Expected argument 'discard_headers' to be a bool")
        pulumi.set(__self__, "discard_headers", discard_headers)
        if follow and not isinstance(follow, bool):
            raise TypeError("Expected argument 'follow' to be a bool")
        pulumi.set(__self__, "follow", follow)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if logs_list_string_enabled and not isinstance(logs_list_string_enabled, bool):
            raise TypeError("Expected argument 'logs_list_string_enabled' to be a bool")
        pulumi.set(__self__, "logs_list_string_enabled", logs_list_string_enabled)
        if logs_list_strings and not isinstance(logs_list_strings, list):
            raise TypeError("Expected argument 'logs_list_strings' to be a list")
        pulumi.set(__self__, "logs_list_strings", logs_list_strings)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if show_stderr and not isinstance(show_stderr, bool):
            raise TypeError("Expected argument 'show_stderr' to be a bool")
        pulumi.set(__self__, "show_stderr", show_stderr)
        if show_stdout and not isinstance(show_stdout, bool):
            raise TypeError("Expected argument 'show_stdout' to be a bool")
        pulumi.set(__self__, "show_stdout", show_stdout)
        if since and not isinstance(since, str):
            raise TypeError("Expected argument 'since' to be a str")
        pulumi.set(__self__, "since", since)
        if tail and not isinstance(tail, str):
            raise TypeError("Expected argument 'tail' to be a str")
        pulumi.set(__self__, "tail", tail)
        if timestamps and not isinstance(timestamps, bool):
            raise TypeError("Expected argument 'timestamps' to be a bool")
        pulumi.set(__self__, "timestamps", timestamps)
        if until and not isinstance(until, str):
            raise TypeError("Expected argument 'until' to be a str")
        pulumi.set(__self__, "until", until)

    @property
    @pulumi.getter
    def details(self) -> Optional[bool]:
        return pulumi.get(self, "details")

    @property
    @pulumi.getter(name="discardHeaders")
    def discard_headers(self) -> Optional[bool]:
        """
        Discard headers that docker appends to each log entry
        """
        return pulumi.get(self, "discard_headers")

    @property
    @pulumi.getter
    def follow(self) -> Optional[bool]:
        return pulumi.get(self, "follow")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="logsListStringEnabled")
    def logs_list_string_enabled(self) -> Optional[bool]:
        """
        If true populate computed value `logs_list_string`
        """
        return pulumi.get(self, "logs_list_string_enabled")

    @property
    @pulumi.getter(name="logsListStrings")
    def logs_list_strings(self) -> Sequence[str]:
        """
        List of container logs, each element is a line.
        """
        return pulumi.get(self, "logs_list_strings")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the Docker Container
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="showStderr")
    def show_stderr(self) -> Optional[bool]:
        return pulumi.get(self, "show_stderr")

    @property
    @pulumi.getter(name="showStdout")
    def show_stdout(self) -> Optional[bool]:
        return pulumi.get(self, "show_stdout")

    @property
    @pulumi.getter
    def since(self) -> Optional[str]:
        return pulumi.get(self, "since")

    @property
    @pulumi.getter
    def tail(self) -> Optional[str]:
        return pulumi.get(self, "tail")

    @property
    @pulumi.getter
    def timestamps(self) -> Optional[bool]:
        return pulumi.get(self, "timestamps")

    @property
    @pulumi.getter
    def until(self) -> Optional[str]:
        return pulumi.get(self, "until")


class AwaitableGetLogsResult(GetLogsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLogsResult(
            details=self.details,
            discard_headers=self.discard_headers,
            follow=self.follow,
            id=self.id,
            logs_list_string_enabled=self.logs_list_string_enabled,
            logs_list_strings=self.logs_list_strings,
            name=self.name,
            show_stderr=self.show_stderr,
            show_stdout=self.show_stdout,
            since=self.since,
            tail=self.tail,
            timestamps=self.timestamps,
            until=self.until)


def get_logs(details: Optional[bool] = None,
             discard_headers: Optional[bool] = None,
             follow: Optional[bool] = None,
             logs_list_string_enabled: Optional[bool] = None,
             name: Optional[str] = None,
             show_stderr: Optional[bool] = None,
             show_stdout: Optional[bool] = None,
             since: Optional[str] = None,
             tail: Optional[str] = None,
             timestamps: Optional[bool] = None,
             until: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLogsResult:
    """
    `get_logs` provides logs from specific container


    :param bool discard_headers: Discard headers that docker appends to each log entry
    :param bool logs_list_string_enabled: If true populate computed value `logs_list_string`
    :param str name: The name of the Docker Container
    """
    __args__ = dict()
    __args__['details'] = details
    __args__['discardHeaders'] = discard_headers
    __args__['follow'] = follow
    __args__['logsListStringEnabled'] = logs_list_string_enabled
    __args__['name'] = name
    __args__['showStderr'] = show_stderr
    __args__['showStdout'] = show_stdout
    __args__['since'] = since
    __args__['tail'] = tail
    __args__['timestamps'] = timestamps
    __args__['until'] = until
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('docker:index/getLogs:getLogs', __args__, opts=opts, typ=GetLogsResult).value

    return AwaitableGetLogsResult(
        details=pulumi.get(__ret__, 'details'),
        discard_headers=pulumi.get(__ret__, 'discard_headers'),
        follow=pulumi.get(__ret__, 'follow'),
        id=pulumi.get(__ret__, 'id'),
        logs_list_string_enabled=pulumi.get(__ret__, 'logs_list_string_enabled'),
        logs_list_strings=pulumi.get(__ret__, 'logs_list_strings'),
        name=pulumi.get(__ret__, 'name'),
        show_stderr=pulumi.get(__ret__, 'show_stderr'),
        show_stdout=pulumi.get(__ret__, 'show_stdout'),
        since=pulumi.get(__ret__, 'since'),
        tail=pulumi.get(__ret__, 'tail'),
        timestamps=pulumi.get(__ret__, 'timestamps'),
        until=pulumi.get(__ret__, 'until'))


@_utilities.lift_output_func(get_logs)
def get_logs_output(details: Optional[pulumi.Input[Optional[bool]]] = None,
                    discard_headers: Optional[pulumi.Input[Optional[bool]]] = None,
                    follow: Optional[pulumi.Input[Optional[bool]]] = None,
                    logs_list_string_enabled: Optional[pulumi.Input[Optional[bool]]] = None,
                    name: Optional[pulumi.Input[str]] = None,
                    show_stderr: Optional[pulumi.Input[Optional[bool]]] = None,
                    show_stdout: Optional[pulumi.Input[Optional[bool]]] = None,
                    since: Optional[pulumi.Input[Optional[str]]] = None,
                    tail: Optional[pulumi.Input[Optional[str]]] = None,
                    timestamps: Optional[pulumi.Input[Optional[bool]]] = None,
                    until: Optional[pulumi.Input[Optional[str]]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetLogsResult]:
    """
    `get_logs` provides logs from specific container


    :param bool discard_headers: Discard headers that docker appends to each log entry
    :param bool logs_list_string_enabled: If true populate computed value `logs_list_string`
    :param str name: The name of the Docker Container
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PluginArgs', 'Plugin']

@pulumi.input_type
class PluginArgs:
    def __init__(__self__, *,
                 alias: Optional[pulumi.Input[str]] = None,
                 enable_timeout: Optional[pulumi.Input[int]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 envs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 force_destroy: Optional[pulumi.Input[bool]] = None,
                 force_disable: Optional[pulumi.Input[bool]] = None,
                 grant_all_permissions: Optional[pulumi.Input[bool]] = None,
                 grant_permissions: Optional[pulumi.Input[Sequence[pulumi.Input['PluginGrantPermissionArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Plugin resource.
        :param pulumi.Input[str] alias: Docker Plugin alias
        :param pulumi.Input[int] enable_timeout: HTTP client timeout to enable the plugin
        :param pulumi.Input[bool] enabled: If `true` the plugin is enabled. Defaults to `true`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] envs: The environment variables in the form of `KEY=VALUE`, e.g. `DEBUG=0`
        :param pulumi.Input[bool] force_destroy: If true, then the plugin is destroyed forcibly
        :param pulumi.Input[bool] force_disable: If true, then the plugin is disabled forcibly
        :param pulumi.Input[bool] grant_all_permissions: If true, grant all permissions necessary to run the plugin
        :param pulumi.Input[Sequence[pulumi.Input['PluginGrantPermissionArgs']]] grant_permissions: Grant specific permissions only
        :param pulumi.Input[str] name: Docker Plugin name
        """
        if alias is not None:
            pulumi.set(__self__, "alias", alias)
        if enable_timeout is not None:
            pulumi.set(__self__, "enable_timeout", enable_timeout)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if envs is not None:
            pulumi.set(__self__, "envs", envs)
        if force_destroy is not None:
            pulumi.set(__self__, "force_destroy", force_destroy)
        if force_disable is not None:
            pulumi.set(__self__, "force_disable", force_disable)
        if grant_all_permissions is not None:
            pulumi.set(__self__, "grant_all_permissions", grant_all_permissions)
        if grant_permissions is not None:
            pulumi.set(__self__, "grant_permissions", grant_permissions)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def alias(self) -> Optional[pulumi.Input[str]]:
        """
        Docker Plugin alias
        """
        return pulumi.get(self, "alias")

    @alias.setter
    def alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alias", value)

    @property
    @pulumi.getter(name="enableTimeout")
    def enable_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        HTTP client timeout to enable the plugin
        """
        return pulumi.get(self, "enable_timeout")

    @enable_timeout.setter
    def enable_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "enable_timeout", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        If `true` the plugin is enabled. Defaults to `true`
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def envs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The environment variables in the form of `KEY=VALUE`, e.g. `DEBUG=0`
        """
        return pulumi.get(self, "envs")

    @envs.setter
    def envs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "envs", value)

    @property
    @pulumi.getter(name="forceDestroy")
    def force_destroy(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, then the plugin is destroyed forcibly
        """
        return pulumi.get(self, "force_destroy")

    @force_destroy.setter
    def force_destroy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "force_destroy", value)

    @property
    @pulumi.getter(name="forceDisable")
    def force_disable(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, then the plugin is disabled forcibly
        """
        return pulumi.get(self, "force_disable")

    @force_disable.setter
    def force_disable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "force_disable", value)

    @property
    @pulumi.getter(name="grantAllPermissions")
    def grant_all_permissions(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, grant all permissions necessary to run the plugin
        """
        return pulumi.get(self, "grant_all_permissions")

    @grant_all_permissions.setter
    def grant_all_permissions(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "grant_all_permissions", value)

    @property
    @pulumi.getter(name="grantPermissions")
    def grant_permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PluginGrantPermissionArgs']]]]:
        """
        Grant specific permissions only
        """
        return pulumi.get(self, "grant_permissions")

    @grant_permissions.setter
    def grant_permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PluginGrantPermissionArgs']]]]):
        pulumi.set(self, "grant_permissions", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Docker Plugin name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _PluginState:
    def __init__(__self__, *,
                 alias: Optional[pulumi.Input[str]] = None,
                 enable_timeout: Optional[pulumi.Input[int]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 envs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 force_destroy: Optional[pulumi.Input[bool]] = None,
                 force_disable: Optional[pulumi.Input[bool]] = None,
                 grant_all_permissions: Optional[pulumi.Input[bool]] = None,
                 grant_permissions: Optional[pulumi.Input[Sequence[pulumi.Input['PluginGrantPermissionArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 plugin_reference: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Plugin resources.
        :param pulumi.Input[str] alias: Docker Plugin alias
        :param pulumi.Input[int] enable_timeout: HTTP client timeout to enable the plugin
        :param pulumi.Input[bool] enabled: If `true` the plugin is enabled. Defaults to `true`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] envs: The environment variables in the form of `KEY=VALUE`, e.g. `DEBUG=0`
        :param pulumi.Input[bool] force_destroy: If true, then the plugin is destroyed forcibly
        :param pulumi.Input[bool] force_disable: If true, then the plugin is disabled forcibly
        :param pulumi.Input[bool] grant_all_permissions: If true, grant all permissions necessary to run the plugin
        :param pulumi.Input[Sequence[pulumi.Input['PluginGrantPermissionArgs']]] grant_permissions: Grant specific permissions only
        :param pulumi.Input[str] name: Docker Plugin name
        :param pulumi.Input[str] plugin_reference: Docker Plugin Reference
        """
        if alias is not None:
            pulumi.set(__self__, "alias", alias)
        if enable_timeout is not None:
            pulumi.set(__self__, "enable_timeout", enable_timeout)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if envs is not None:
            pulumi.set(__self__, "envs", envs)
        if force_destroy is not None:
            pulumi.set(__self__, "force_destroy", force_destroy)
        if force_disable is not None:
            pulumi.set(__self__, "force_disable", force_disable)
        if grant_all_permissions is not None:
            pulumi.set(__self__, "grant_all_permissions", grant_all_permissions)
        if grant_permissions is not None:
            pulumi.set(__self__, "grant_permissions", grant_permissions)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if plugin_reference is not None:
            pulumi.set(__self__, "plugin_reference", plugin_reference)

    @property
    @pulumi.getter
    def alias(self) -> Optional[pulumi.Input[str]]:
        """
        Docker Plugin alias
        """
        return pulumi.get(self, "alias")

    @alias.setter
    def alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alias", value)

    @property
    @pulumi.getter(name="enableTimeout")
    def enable_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        HTTP client timeout to enable the plugin
        """
        return pulumi.get(self, "enable_timeout")

    @enable_timeout.setter
    def enable_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "enable_timeout", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        If `true` the plugin is enabled. Defaults to `true`
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def envs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The environment variables in the form of `KEY=VALUE`, e.g. `DEBUG=0`
        """
        return pulumi.get(self, "envs")

    @envs.setter
    def envs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "envs", value)

    @property
    @pulumi.getter(name="forceDestroy")
    def force_destroy(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, then the plugin is destroyed forcibly
        """
        return pulumi.get(self, "force_destroy")

    @force_destroy.setter
    def force_destroy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "force_destroy", value)

    @property
    @pulumi.getter(name="forceDisable")
    def force_disable(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, then the plugin is disabled forcibly
        """
        return pulumi.get(self, "force_disable")

    @force_disable.setter
    def force_disable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "force_disable", value)

    @property
    @pulumi.getter(name="grantAllPermissions")
    def grant_all_permissions(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, grant all permissions necessary to run the plugin
        """
        return pulumi.get(self, "grant_all_permissions")

    @grant_all_permissions.setter
    def grant_all_permissions(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "grant_all_permissions", value)

    @property
    @pulumi.getter(name="grantPermissions")
    def grant_permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PluginGrantPermissionArgs']]]]:
        """
        Grant specific permissions only
        """
        return pulumi.get(self, "grant_permissions")

    @grant_permissions.setter
    def grant_permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PluginGrantPermissionArgs']]]]):
        pulumi.set(self, "grant_permissions", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Docker Plugin name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="pluginReference")
    def plugin_reference(self) -> Optional[pulumi.Input[str]]:
        """
        Docker Plugin Reference
        """
        return pulumi.get(self, "plugin_reference")

    @plugin_reference.setter
    def plugin_reference(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "plugin_reference", value)


class Plugin(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alias: Optional[pulumi.Input[str]] = None,
                 enable_timeout: Optional[pulumi.Input[int]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 envs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 force_destroy: Optional[pulumi.Input[bool]] = None,
                 force_disable: Optional[pulumi.Input[bool]] = None,
                 grant_all_permissions: Optional[pulumi.Input[bool]] = None,
                 grant_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PluginGrantPermissionArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        <!-- Bug: Type and Name are switched -->
        Manages the lifecycle of a Docker plugin.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_docker as docker

        sample_volume_plugin = docker.Plugin("sample-volume-plugin",
            alias="sample-volume-plugin",
            enable_timeout=60,
            enabled=False,
            envs=["DEBUG=1"],
            force_destroy=True,
            force_disable=True,
            grant_all_permissions=True)
        ```

        ## Import

        #!/bin/bash

        ```sh
         $ pulumi import docker:index/plugin:Plugin sample-volume-plugin "$(docker plugin inspect -f {{.ID}} tiborvass/sample-volume-plugin:latest)"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] alias: Docker Plugin alias
        :param pulumi.Input[int] enable_timeout: HTTP client timeout to enable the plugin
        :param pulumi.Input[bool] enabled: If `true` the plugin is enabled. Defaults to `true`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] envs: The environment variables in the form of `KEY=VALUE`, e.g. `DEBUG=0`
        :param pulumi.Input[bool] force_destroy: If true, then the plugin is destroyed forcibly
        :param pulumi.Input[bool] force_disable: If true, then the plugin is disabled forcibly
        :param pulumi.Input[bool] grant_all_permissions: If true, grant all permissions necessary to run the plugin
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PluginGrantPermissionArgs']]]] grant_permissions: Grant specific permissions only
        :param pulumi.Input[str] name: Docker Plugin name
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[PluginArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        <!-- Bug: Type and Name are switched -->
        Manages the lifecycle of a Docker plugin.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_docker as docker

        sample_volume_plugin = docker.Plugin("sample-volume-plugin",
            alias="sample-volume-plugin",
            enable_timeout=60,
            enabled=False,
            envs=["DEBUG=1"],
            force_destroy=True,
            force_disable=True,
            grant_all_permissions=True)
        ```

        ## Import

        #!/bin/bash

        ```sh
         $ pulumi import docker:index/plugin:Plugin sample-volume-plugin "$(docker plugin inspect -f {{.ID}} tiborvass/sample-volume-plugin:latest)"
        ```

        :param str resource_name: The name of the resource.
        :param PluginArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PluginArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alias: Optional[pulumi.Input[str]] = None,
                 enable_timeout: Optional[pulumi.Input[int]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 envs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 force_destroy: Optional[pulumi.Input[bool]] = None,
                 force_disable: Optional[pulumi.Input[bool]] = None,
                 grant_all_permissions: Optional[pulumi.Input[bool]] = None,
                 grant_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PluginGrantPermissionArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PluginArgs.__new__(PluginArgs)

            __props__.__dict__["alias"] = alias
            __props__.__dict__["enable_timeout"] = enable_timeout
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["envs"] = envs
            __props__.__dict__["force_destroy"] = force_destroy
            __props__.__dict__["force_disable"] = force_disable
            __props__.__dict__["grant_all_permissions"] = grant_all_permissions
            __props__.__dict__["grant_permissions"] = grant_permissions
            __props__.__dict__["name"] = name
            __props__.__dict__["plugin_reference"] = None
        super(Plugin, __self__).__init__(
            'docker:index/plugin:Plugin',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alias: Optional[pulumi.Input[str]] = None,
            enable_timeout: Optional[pulumi.Input[int]] = None,
            enabled: Optional[pulumi.Input[bool]] = None,
            envs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            force_destroy: Optional[pulumi.Input[bool]] = None,
            force_disable: Optional[pulumi.Input[bool]] = None,
            grant_all_permissions: Optional[pulumi.Input[bool]] = None,
            grant_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PluginGrantPermissionArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            plugin_reference: Optional[pulumi.Input[str]] = None) -> 'Plugin':
        """
        Get an existing Plugin resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] alias: Docker Plugin alias
        :param pulumi.Input[int] enable_timeout: HTTP client timeout to enable the plugin
        :param pulumi.Input[bool] enabled: If `true` the plugin is enabled. Defaults to `true`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] envs: The environment variables in the form of `KEY=VALUE`, e.g. `DEBUG=0`
        :param pulumi.Input[bool] force_destroy: If true, then the plugin is destroyed forcibly
        :param pulumi.Input[bool] force_disable: If true, then the plugin is disabled forcibly
        :param pulumi.Input[bool] grant_all_permissions: If true, grant all permissions necessary to run the plugin
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['PluginGrantPermissionArgs']]]] grant_permissions: Grant specific permissions only
        :param pulumi.Input[str] name: Docker Plugin name
        :param pulumi.Input[str] plugin_reference: Docker Plugin Reference
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PluginState.__new__(_PluginState)

        __props__.__dict__["alias"] = alias
        __props__.__dict__["enable_timeout"] = enable_timeout
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["envs"] = envs
        __props__.__dict__["force_destroy"] = force_destroy
        __props__.__dict__["force_disable"] = force_disable
        __props__.__dict__["grant_all_permissions"] = grant_all_permissions
        __props__.__dict__["grant_permissions"] = grant_permissions
        __props__.__dict__["name"] = name
        __props__.__dict__["plugin_reference"] = plugin_reference
        return Plugin(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def alias(self) -> pulumi.Output[str]:
        """
        Docker Plugin alias
        """
        return pulumi.get(self, "alias")

    @property
    @pulumi.getter(name="enableTimeout")
    def enable_timeout(self) -> pulumi.Output[Optional[int]]:
        """
        HTTP client timeout to enable the plugin
        """
        return pulumi.get(self, "enable_timeout")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        If `true` the plugin is enabled. Defaults to `true`
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def envs(self) -> pulumi.Output[Sequence[str]]:
        """
        The environment variables in the form of `KEY=VALUE`, e.g. `DEBUG=0`
        """
        return pulumi.get(self, "envs")

    @property
    @pulumi.getter(name="forceDestroy")
    def force_destroy(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, then the plugin is destroyed forcibly
        """
        return pulumi.get(self, "force_destroy")

    @property
    @pulumi.getter(name="forceDisable")
    def force_disable(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, then the plugin is disabled forcibly
        """
        return pulumi.get(self, "force_disable")

    @property
    @pulumi.getter(name="grantAllPermissions")
    def grant_all_permissions(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, grant all permissions necessary to run the plugin
        """
        return pulumi.get(self, "grant_all_permissions")

    @property
    @pulumi.getter(name="grantPermissions")
    def grant_permissions(self) -> pulumi.Output[Optional[Sequence['outputs.PluginGrantPermission']]]:
        """
        Grant specific permissions only
        """
        return pulumi.get(self, "grant_permissions")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Docker Plugin name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="pluginReference")
    def plugin_reference(self) -> pulumi.Output[str]:
        """
        Docker Plugin Reference
        """
        return pulumi.get(self, "plugin_reference")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VolumeArgs', 'Volume']

@pulumi.input_type
class VolumeArgs:
    def __init__(__self__, *,
                 driver: Optional[pulumi.Input[str]] = None,
                 driver_opts: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input['VolumeLabelArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Volume resource.
        :param pulumi.Input[str] driver: Driver type for the volume. Defaults to `local`.
        :param pulumi.Input[Mapping[str, Any]] driver_opts: Options specific to the driver.
        :param pulumi.Input[Sequence[pulumi.Input['VolumeLabelArgs']]] labels: User-defined key/value metadata
        :param pulumi.Input[str] name: The name of the Docker volume (will be generated if not provided).
        """
        if driver is not None:
            pulumi.set(__self__, "driver", driver)
        if driver_opts is not None:
            pulumi.set(__self__, "driver_opts", driver_opts)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def driver(self) -> Optional[pulumi.Input[str]]:
        """
        Driver type for the volume. Defaults to `local`.
        """
        return pulumi.get(self, "driver")

    @driver.setter
    def driver(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "driver", value)

    @property
    @pulumi.getter(name="driverOpts")
    def driver_opts(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Options specific to the driver.
        """
        return pulumi.get(self, "driver_opts")

    @driver_opts.setter
    def driver_opts(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "driver_opts", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VolumeLabelArgs']]]]:
        """
        User-defined key/value metadata
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VolumeLabelArgs']]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Docker volume (will be generated if not provided).
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _VolumeState:
    def __init__(__self__, *,
                 driver: Optional[pulumi.Input[str]] = None,
                 driver_opts: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input['VolumeLabelArgs']]]] = None,
                 mountpoint: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Volume resources.
        :param pulumi.Input[str] driver: Driver type for the volume. Defaults to `local`.
        :param pulumi.Input[Mapping[str, Any]] driver_opts: Options specific to the driver.
        :param pulumi.Input[Sequence[pulumi.Input['VolumeLabelArgs']]] labels: User-defined key/value metadata
        :param pulumi.Input[str] mountpoint: The mountpoint of the volume.
        :param pulumi.Input[str] name: The name of the Docker volume (will be generated if not provided).
        """
        if driver is not None:
            pulumi.set(__self__, "driver", driver)
        if driver_opts is not None:
            pulumi.set(__self__, "driver_opts", driver_opts)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if mountpoint is not None:
            pulumi.set(__self__, "mountpoint", mountpoint)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def driver(self) -> Optional[pulumi.Input[str]]:
        """
        Driver type for the volume. Defaults to `local`.
        """
        return pulumi.get(self, "driver")

    @driver.setter
    def driver(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "driver", value)

    @property
    @pulumi.getter(name="driverOpts")
    def driver_opts(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Options specific to the driver.
        """
        return pulumi.get(self, "driver_opts")

    @driver_opts.setter
    def driver_opts(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "driver_opts", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VolumeLabelArgs']]]]:
        """
        User-defined key/value metadata
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VolumeLabelArgs']]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def mountpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The mountpoint of the volume.
        """
        return pulumi.get(self, "mountpoint")

    @mountpoint.setter
    def mountpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mountpoint", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Docker volume (will be generated if not provided).
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class Volume(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 driver: Optional[pulumi.Input[str]] = None,
                 driver_opts: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VolumeLabelArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        <!-- Bug: Type and Name are switched -->
        Creates and destroys a volume in Docker. This can be used alongside Container to prepare volumes that can be shared across containers.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_docker as docker

        shared_volume = docker.Volume("sharedVolume")
        ```

        ## Import

        ### Example Assuming you created a `volume` as follows #!/bin/bash docker volume create prints the long ID 524b0457aa2a87dd2b75c74c3e4e53f406974249e63ab3ed9bf21e5644f9dc7d you provide the definition for the resource as follows terraform resource "docker_volume" "foo" {

         name = "524b0457aa2a87dd2b75c74c3e4e53f406974249e63ab3ed9bf21e5644f9dc7d" } then the import command is as follows #!/bin/bash

        ```sh
         $ pulumi import docker:index/volume:Volume foo 524b0457aa2a87dd2b75c74c3e4e53f406974249e63ab3ed9bf21e5644f9dc7d
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] driver: Driver type for the volume. Defaults to `local`.
        :param pulumi.Input[Mapping[str, Any]] driver_opts: Options specific to the driver.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VolumeLabelArgs']]]] labels: User-defined key/value metadata
        :param pulumi.Input[str] name: The name of the Docker volume (will be generated if not provided).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[VolumeArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        <!-- Bug: Type and Name are switched -->
        Creates and destroys a volume in Docker. This can be used alongside Container to prepare volumes that can be shared across containers.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_docker as docker

        shared_volume = docker.Volume("sharedVolume")
        ```

        ## Import

        ### Example Assuming you created a `volume` as follows #!/bin/bash docker volume create prints the long ID 524b0457aa2a87dd2b75c74c3e4e53f406974249e63ab3ed9bf21e5644f9dc7d you provide the definition for the resource as follows terraform resource "docker_volume" "foo" {

         name = "524b0457aa2a87dd2b75c74c3e4e53f406974249e63ab3ed9bf21e5644f9dc7d" } then the import command is as follows #!/bin/bash

        ```sh
         $ pulumi import docker:index/volume:Volume foo 524b0457aa2a87dd2b75c74c3e4e53f406974249e63ab3ed9bf21e5644f9dc7d
        ```

        :param str resource_name: The name of the resource.
        :param VolumeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VolumeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 driver: Optional[pulumi.Input[str]] = None,
                 driver_opts: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VolumeLabelArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VolumeArgs.__new__(VolumeArgs)

            __props__.__dict__["driver"] = driver
            __props__.__dict__["driver_opts"] = driver_opts
            __props__.__dict__["labels"] = labels
            __props__.__dict__["name"] = name
            __props__.__dict__["mountpoint"] = None
        super(Volume, __self__).__init__(
            'docker:index/volume:Volume',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            driver: Optional[pulumi.Input[str]] = None,
            driver_opts: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            labels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VolumeLabelArgs']]]]] = None,
            mountpoint: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'Volume':
        """
        Get an existing Volume resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] driver: Driver type for the volume. Defaults to `local`.
        :param pulumi.Input[Mapping[str, Any]] driver_opts: Options specific to the driver.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VolumeLabelArgs']]]] labels: User-defined key/value metadata
        :param pulumi.Input[str] mountpoint: The mountpoint of the volume.
        :param pulumi.Input[str] name: The name of the Docker volume (will be generated if not provided).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VolumeState.__new__(_VolumeState)

        __props__.__dict__["driver"] = driver
        __props__.__dict__["driver_opts"] = driver_opts
        __props__.__dict__["labels"] = labels
        __props__.__dict__["mountpoint"] = mountpoint
        __props__.__dict__["name"] = name
        return Volume(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def driver(self) -> pulumi.Output[str]:
        """
        Driver type for the volume. Defaults to `local`.
        """
        return pulumi.get(self, "driver")

    @property
    @pulumi.getter(name="driverOpts")
    def driver_opts(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        Options specific to the driver.
        """
        return pulumi.get(self, "driver_opts")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Optional[Sequence['outputs.VolumeLabel']]]:
        """
        User-defined key/value metadata
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def mountpoint(self) -> pulumi.Output[str]:
        """
        The mountpoint of the volume.
        """
        return pulumi.get(self, "mountpoint")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Docker volume (will be generated if not provided).
        """
        return pulumi.get(self, "name")

